<?php
/**
 * $Horde: trean/browse.php,v 1.49 2005/04/25 21:39:59 chuck Exp $
 *
 * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('TREAN_BASE', dirname(__FILE__));
require_once TREAN_BASE . '/lib/base.php';
require_once 'Horde/Tree.php';
require_once 'Horde/Template.php';

/* The URL that the category tree and categories list will be linking to. */
$base_url = 'browse.php';

/* Get bookmarks to display. */
$category_id = Util::getFormData('category_id', $trean_shares->getId(Auth::getAuth()));
$category = &$trean_shares->getCategory($category_id);

/* Make sure user has permission to view this category. */
if (!$category->hasPermission(Auth::getAuth(), PERMS_READ)) {
    $notification->push(_("You do not have permission to view this category."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('browse.php', true));
    exit;
}

/* Get category contents. */
$bookmarks = $category->listBookmarks();
$subcategories = Trean::listCategories(PERMS_SHOW, null, $category->getName(), false);

/* Get full categories tree to display. */
$category_tree = Trean::listCategories();

/* Set up the tree. */
$params = array('icondir' => $registry->getImageDir('horde') . '/tree',
                'icon' => 'folder.png',
                'iconopen' => 'folderopen.png');

$tree = &Horde_Tree::factory('category_tree', 'javascript');
$tree->setOption(array('class' => 'item', 'alternate' => true));
$expandTree = $prefs->getValue('expand_tree');

foreach ($category_tree as $node_id => $node_val) {
    $parent_id = $trean_shares->getName($trean_shares->getParent($node_val));
    $indent = substr_count($node_id, ':');
    $label = $node_val->get('name');

    if ($node_val->get('owner') == Auth::getAuth()) {
        $expanded = ($expandTree == 'all') || ($parent_id == DATATREE_ROOT && $expandTree == 'first');
    } else {
        $expanded = false;
    }

    /* Selected or not? */
    $class = ($node_id == $trean_shares->getName($category_id)) ? array('class' => 'selected') : array();

    /* The clickable url for each node. */
    $params['url'] = Util::addParameter(Horde::applicationUrl('browse.php'), 'category_id', $trean_shares->getId($node_id));

    if ($parent_id == DATATREE_ROOT) {
        $parent_id = null;
        //$label = _("My Bookmarks");
    }

    /* Add the node and add the node params. */
    $tree->addNode($node_id, $parent_id, $label,
                   $indent, $expanded, $params + $class);
}

$template = &new Horde_Template();
$template->setOption('gettext', true);
$template->set('category_tree', Util::bufferOutput(array($tree, 'renderTree')));
$template->set('bookmarks', Util::bufferOutput('require', TREAN_TEMPLATES . '/browse/bookmarks.inc'));
if (count($subcategories)) {
    $template->set('subcategories', Util::bufferOutput('require', TREAN_TEMPLATES . '/browse/subcategories.inc'));
} else {
    $template->set('subcategories', '');
}

$title = _("Browse");
Horde::addScriptFile('popup.js', 'horde', true);
if (count($subcategories)) {
    Horde::addScriptFile('stripe.js', 'horde', true);
}
require TREAN_TEMPLATES . '/common-header.inc';
require TREAN_TEMPLATES . '/menu.inc';
require TREAN_TEMPLATES . '/browse/javascript.inc';
echo $template->fetch(TREAN_TEMPLATES . '/browse/browse.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
